<?php
// https://smartmailer.cz/docs/

class Api
{
    /**
     * @var string|null
     */
    private $accessToken = null;
    private $url = 'smartmailer.cz';
    private $version = 'v1';


    /**
     * @param string $accessToken
     * @throws Exception
     */
    public function __construct($accessToken)
    {
        $this->setAccessToken($accessToken);
    }


    /**
     * @param string $token
     * @throws Exception
     */
    public function setAccessToken($token)
    {
        if ($token === '') {
            throw new Exception('Invalid token');
        }
        $this->accessToken = $token;
    }


    public function checkToken()
    {
        $ch = curl_init('https://' . $this->url . '/api/' . $this->version . '/check/token');

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        curl_exec($ch);
        $info = curl_getinfo($ch);
        curl_close($ch);

        return $info;
    }

    public function ConversionWH($uuid, $count)
    {
        if (!$uuid) {
            throw new Exception('Invalid campaign UUID');
        } elseif (!$count) {
            throw new Exception('Invalid conversion add/remove count');
        }

        $ch = curl_init('https://' . $this->url . '/api/' . $this->version . '/campaign/' . $uuid . "/conversion/$count");


        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $data = curl_exec($ch);

        $info = curl_getinfo($ch);
        /*
        echo '<pre>';
        var_dump($this->accessToken);
        var_dump($info);
        echo '</pre>';
        */

        curl_close($ch);

        // return $info;
        return $data;
    }


    public function UnsubscribeWH($uuid, $contacts, $bookUuid = false)
    {
        if (!$uuid) {
            throw new Exception('Invalid campaign UUID');
        } elseif (!$contacts) {
            throw new Exception('Invalid contacts for unsubscribe');
        }

        $ch = curl_init('https://' . $this->url . '/api/' . $this->version . '/campaign/' . $uuid . "/un-subscribe");


        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        $json = json_encode($contacts);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));


        $data = curl_exec($ch);
        /*
            $info = curl_getinfo($ch);
                echo '<pre>';
            var_dump($this->accessToken);
            var_dump($contacts);
            var_dump($info);
            echo '</pre>';
            */


        curl_close($ch);

        // return $info;
        return $data;
    }


    /**
     * @param string $uuid
     * @return bool|string
     * @throws Exception
     */
    public function deleteContact($uuid)
    {
        if (!$uuid) {
            throw new Exception('Invalid contact UUID');
        }

        $ch = curl_init('https://' . $this->url . '/api/' . $this->version . '/contacts/' . $uuid);

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $data = curl_exec($ch);
        $info = curl_getinfo($ch);

        curl_close($ch);

        // return $info;
        return $data;
    }


    /**
     * @param array  $contacts
     * @param string $addressBookUuid
     * @return bool|string
     */
    public function deleteContacts($contacts, $addressBookUuid)
    {
        $ch = curl_init('https://' . $this->url . '/api/' . $this->version . '/addressbook/' . $addressBookUuid . '/contacts');

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));

        $json = json_encode($contacts);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

        $data = curl_exec($ch);
        $info = curl_getinfo($ch);

        curl_close($ch);

        // return $info;
        return $data;
    }


    /**
     * @throws JsonException
     */
    public function insertContacts($addressBookUuid, $contacts)
    {
        if (!$addressBookUuid) {
            throw new Exception('Invalid AddressBook UUID');
        }

        if (empty($contacts)) {
            throw new Exception('No contacts');
        }

        $ch = curl_init('https://' . $this->url . '/api/' . $this->version . '/addressbook/' . $addressBookUuid . '/contacts');

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');

        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->accessToken
        ));


        // $json = json_encode($contacts, JSON_THROW_ON_ERROR);
        $json = json_encode($contacts);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

        $data = curl_exec($ch);
        // print_R($data);
        $info = curl_getinfo($ch);
        /*
        echo '<pre>';
        var_dump($this->accessToken);
        var_dump($addressBookUuid);
        var_dump($contacts);
        var_dump($info);
        echo '</pre>';
        */

        curl_close($ch);

        // return $info;
        return $data;
    }
}
